<?php

	/**
	 * List of available shortcodes
	 */
	function su_shortcodes( $shortcode = false ) {
		$shortcodes = array(
			# heading
			'heading' => array(
				'name' => 'Heading',
				'type' => 'wrap',
				'atts' => array(
					'style' => array(
						'values' => array(
							'1',
							'2'
						),
						'desc' => __( 'Heading style', 'satori' )
					)
				),
				'usage' => '[heading] Content [/heading]<br/>[heading style="2"] Content [/heading]',
				'content' => __( 'Heading', 'satori' ),
				'desc' => __( 'Styled heading', 'satori' )
			),
			# frame
			'frame' => array(
				'name' => 'Image frame',
				'type' => 'wrap',
				'atts' => array(
					'align' => array(
						'values' => array(
							'left',
							'center',
							'none',
							'right'
						),
						'desc' => __( 'Frame align', 'satori' )
					)
				),
				'usage' => '[frame align="center"] <img src="image.jpg" alt="" /> [/frame]',
				'content' => __( 'Image tag', 'satori' ),
				'desc' => __( 'Styled image frame', 'satori' )
			),
			# tabs
			'tabs' => array(
				'name' => 'Tabs',
				'type' => 'wrap',
				'atts' => array(
					'style' => array(
						'values' => array(
							'1',
							'2',
							'3'
						),
						'default' => '1',
						'desc' => __( 'Tabs style', 'satori' )
					)
				),
				'usage' => '[tabs style="1"] [tab title="Tab name"] Tab content [/tab] [/tabs]',
				'desc' => __( 'Tabs container', 'satori' )
			),
			# tab
			'tab' => array(
				'name' => 'Tab',
				'type' => 'wrap',
				'atts' => array(
					'title' => array(
						'values' => array( ),
						'default' => __( 'Title', 'satori' ),
						'desc' => __( 'Tab title', 'satori' )
					)
				),
				'usage' => '[tabs style="1"] [tab title="Tab name"] Tab content [/tab] [/tabs]',
				'content' => __( 'Tab content', 'satori' ),
				'desc' => __( 'Single tab', 'satori' )
			),
			# spoiler
			'spoiler' => array(
				'name' => 'Spoiler',
				'type' => 'wrap',
				'atts' => array(
					'title' => array(
						'values' => array( ),
						'default' => __( 'Spoiler title', 'satori' ),
						'desc' => __( 'Spoiler title', 'satori' )
					),
					'open' => array(
						'values' => array(
							'0',
							'1'
						),
						'default' => '0',
						'desc' => __( 'Is spoiler open?', 'satori' )
					),
					'style' => array(
						'values' => array(
							'1',
							'2'
						),
						'default' => '1',
						'desc' => __( 'Spoiler style', 'satori' )
					)
				),
				'usage' => '[spoiler title="Spoiler title"] Hidden text [/spoiler]',
				'content' => __( 'Hidden content', 'satori' ),
				'desc' => __( 'Hidden text', 'satori' )
			),
			# accordion
			'accordion' => array(
				'name' => 'Accordion',
				'type' => 'wrap',
				'atts' => array( ),
				'usage' => '[accordion]<br/>[spoiler open="true"] content [/spoiler]<br/>[spoiler] content [/spoiler]<br/>[spoiler] content [/spoiler]<br/>[/accordion]',
				'content' => '[spoiler] content [/spoiler]',
				'desc' => __( 'Accordion', 'satori' )
			),
			# divider
			'divider' => array(
				'name' => 'Divider',
				'type' => 'single',
				'atts' => array(
					'top' => array(
						'values' => array(
							'0',
							'1'
						),
						'default' => '0',
						'desc' => __( 'Show TOP link', 'satori' )
					)
				),
				'usage' => '[divider top="1"]',
				'desc' => __( 'Content divider with optional TOP link', 'satori' )
			),
			# spacer
			'spacer' => array(
				'name' => 'Spacer',
				'type' => 'single',
				'atts' => array(
					'size' => array(
						'values' => array(
							'0',
							'5',
							'10',
							'20',
							'40'
						),
						'default' => '20',
						'desc' => __( 'Spacer height in pixels', 'satori' )
					)
				),
				'usage' => '[spacer size="20"]',
				'desc' => __( 'Empty space with adjustable height', 'satori' )
			),
			# quote
			'quote' => array(
				'name' => 'Quote',
				'type' => 'wrap',
				'atts' => array(
					'style' => array(
						'values' => array(
							'1',
							'2',
							'3'
						),
						'default' => '1',
						'desc' => __( 'Quote style', 'satori' )
					)
				),
				'usage' => '[quote style="1"] Content [/quote]',
				'content' => __( 'Quote', 'satori' ),
				'desc' => __( 'Blockquote alternative', 'satori' )
			),
			# pullquote
			'pullquote' => array(
				'name' => 'Pullquote',
				'type' => 'wrap',
				'atts' => array(
					'align' => array(
						'values' => array(
							'left',
							'right'
						),
						'default' => 'left',
						'desc' => __( 'Pullquote alignment', 'satori' )
					)
				),
				'usage' => '[pullquote align="left"] Content [/pullquote]',
				'content' => __( 'Pullquote', 'satori' ),
				'desc' => __( 'Pullquote', 'satori' )
			),
			# highlight
			'highlight' => array(
				'name' => 'Highlight',
				'type' => 'wrap',
				'atts' => array(
					'bg' => array(
						'values' => array( ),
						'default' => '#DDFF99',
						'desc' => __( 'Background color', 'satori' ),
						'type' => 'color'
					),
					'color' => array(
						'values' => array( ),
						'default' => '#000000',
						'desc' => __( 'Text color', 'satori' ),
						'type' => 'color'
					)
				),
				'usage' => '[highlight bg="#fc0" color="#000"] Content [/highlight]',
				'content' => __( 'Highlighted text', 'satori' ),
				'desc' => __( 'Highlighted text', 'satori' )
			),
			# label
			'label' => array(
				'name' => 'Label',
				'type' => 'wrap',
				'atts' => array(
					'style' => array(
						'values' => array(
							'default',
							'success',
							'warning',
							'important',
							'info'
						),
						'default' => 'default',
						'desc' => __( 'Label style', 'satori' )
					)
				),
				'usage' => '[label style="info"]Something[/label]',
				'content' => __( 'Label', 'satori' ),
				'desc' => __( 'Styled label', 'satori' )
			),
			# dropcap
			'dropcap' => array(
				'name' => 'Dropcap',
				'type' => 'wrap',
				'atts' => array(
					'style' => array(
						'values' => array(
							'1',
							'2',
							'3'
						),
						'default' => '1',
						'desc' => __( 'Dropcap style', 'satori' )
					),
					'size' => array(
						'values' => array(
							'1',
							'2',
							'3',
							'4',
							'5'
						),
						'default' => '3',
						'desc' => __( 'Dropcap size', 'satori' )
					)
				),
				'usage' => '[dropcap style="1"]D[/dropcap]ropcap',
				'content' => __( 'D', 'satori' ),
				'desc' => __( 'Dropcap', 'satori' )
			),
			# bloginfo
			'bloginfo' => array(
				'name' => 'Bloginfo',
				'type' => 'single',
				'atts' => array(
					'option' => array(
						'values' => array(
							'name',
							'description',
							'siteurl',
							'admin_email',
							'charset',
							'version',
							'html_type',
							'text_direction',
							'language',
							'template_url',
							'pingback_url',
							'rss2_url'
						),
						'default' => 'left',
						'desc' => __( 'Option name', 'satori' )
					)
				),
				'usage' => '[bloginfo option="name"]',
				'desc' => __( 'Blog info', 'satori' )
			),
			# permalink
			'permalink' => array(
				'name' => 'Permalink',
				'type' => 'mixed',
				'atts' => array(
					'p' => array(
						'values' => array( ),
						'default' => '1',
						'desc' => __( 'Post/page ID', 'satori' )
					),
					'target' => array(
						'values' => array(
							'self',
							'blank'
						),
						'default' => 'self',
						'desc' => __( 'Link target', 'satori' )
					),
				),
				'usage' => '[permalink p=52]<br/>[permalink p="52" target="blank"] Content [/permalink]',
				'content' => __( 'Permalink text', 'satori' ),
				'desc' => __( 'Permalink to specified post/page', 'satori' )
			),
			# button
			'button' => array(
				'name' => 'Button',
				'type' => 'wrap',
				'atts' => array(
					'link' => array(
						'values' => array( ),
						'default' => '#',
						'desc' => __( 'Button link', 'satori' )
					),
					'color' => array(
						'values' => array( ),
						'default' => '#AAAAAA',
						'desc' => __( 'Button background color', 'satori' ),
						'type' => 'color'
					),
					'size' => array(
						'values' => array(
							'1',
							'2',
							'3',
							'4',
							'5',
							'6',
							'7',
							'8',
							'9',
							'10',
							'11',
							'12'
						),
						'default' => '3',
						'desc' => __( 'Button size', 'satori' )
					),
					'style' => array(
						'values' => array(
							'1',
							'2',
							'3',
							'4',
							'5'
						),
						'default' => '1',
						'desc' => __( 'Button background style', 'satori' )
					),
					'dark' => array(
						'values' => array(
							'0',
							'1'
						),
						'default' => '0',
						'desc' => __( 'Dark text color', 'satori' )
					),
					'radius' => array(
						'values' => array(
							'auto',
							'0',
							'5',
							'10',
							'20'
						),
						'default' => 'auto',
						'desc' => __( 'Corners radius', 'satori' )
					),
					'icon' => array(
						'values' => array( ),
						'default' => '',
						'desc' => __( 'Button icon', 'satori' )
					),
					'class' => array(
						'values' => array( ),
						'default' => '',
						'desc' => __( 'Button class', 'satori' )
					),
					'target' => array(
						'values' => array(
							'self',
							'blank'
						),
						'default' => 'self',
						'desc' => __( 'Button link target', 'satori' )
					)
				),
				'usage' => '[button link="#" color="#b00" size="3" style="3" dark="1" square="1" icon="image.png"] Button text [/button]',
				'content' => __( 'Button text', 'satori' ),
				'desc' => __( 'Styled button', 'satori' )
			),
			# fancy_link
			'fancy_link' => array(
				'name' => 'Fancy link',
				'type' => 'wrap',
				'atts' => array(
					'color' => array(
						'values' => array(
							'black',
							'white'
						),
						'default' => 'black',
						'desc' => __( 'Link color', 'satori' )
					),
					'link' => array(
						'values' => array( ),
						'default' => '#',
						'desc' => __( 'URL', 'satori' )
					)
				),
				'usage' => '[fancy_link color="black" link="http://example.com/"] Read more [/fancy_link]',
				'content' => __( 'Link text', 'satori' ),
				'desc' => __( 'Fancy link', 'satori' )
			),
			# service
			'service' => array(
				'name' => 'Service',
				'type' => 'wrap',
				'atts' => array(
					'title' => array(
						'values' => array( ),
						'default' => __( 'Service title', 'satori' ),
						'desc' => __( 'Service title', 'satori' )
					),
					'icon' => array(
						'values' => array( ),
						'default' => '',
						'desc' => __( 'Service icon', 'satori' )
					),
					'size' => array(
						'values' => array(
							'24',
							'32',
							'48'
						),
						'default' => '32',
						'desc' => __( 'Icon size', 'satori' )
					)
				),
				'usage' => '[service title="Service title" icon="service.png" size="32"] Service description [/service]',
				'content' => __( 'Service description', 'satori' ),
				'desc' => __( 'Service box with title', 'satori' )
			),
			# members
			'members' => array(
				'name' => 'Members',
				'type' => 'wrap',
				'atts' => array(
					'style' => array(
						'values' => array(
							'0',
							'1',
							'2'
						),
						'default' => '1',
						'desc' => __( 'Box style', 'satori' )
					),
					'login' => array(
						'values' => array(
							'0',
							'1'
						),
						'default' => '1',
						'desc' => __( 'Show login message', 'satori' )
					)
				),
				'usage' => '[members style="2" login="1"] Content for logged members [/members]',
				'content' => __( 'Content for logged members', 'satori' ),
				'desc' => __( 'Content for logged in members only', 'satori' )
			),
			# guests
			'guests' => array(
				'name' => 'Guests',
				'type' => 'wrap',
				'atts' => array( ),
				'usage' => '[guests] Content for guests [/guests]',
				'content' => __( 'Content for guests', 'satori' ),
				'desc' => __( 'Content for guests only', 'satori' )
			),
			# box
			'box' => array(
				'name' => 'Box',
				'type' => 'wrap',
				'atts' => array(
					'title' => array(
						'values' => array( ),
						'default' => __( 'Box title', 'satori' ),
						'desc' => __( 'Box title', 'satori' )
					),
					'color' => array(
						'values' => array( ),
						'default' => '#333333',
						'desc' => __( 'Box color', 'satori' ),
						'type' => 'color'
					)
				),
				'usage' => '[box title="Box title" color="#f00"] Content [/box]',
				'content' => __( 'Box content', 'satori' ),
				'desc' => __( 'Colored box with caption', 'satori' )
			),
			# note
			'note' => array(
				'name' => 'Note',
				'type' => 'wrap',
				'atts' => array(
					'color' => array(
						'values' => array( ),
						'default' => '#FFCC00',
						'desc' => __( 'Note color', 'satori' ),
						'type' => 'color'
					)
				),
				'usage' => '[note color="#FFCC00"] Content [/note]',
				'content' => __( 'Note text', 'satori' ),
				'desc' => __( 'Colored box', 'satori' )
			),
			# private
			'private' => array(
				'name' => 'Private',
				'type' => 'wrap',
				'atts' => array( ),
				'usage' => '[private] Private content [/private]',
				'content' => __( 'Private note text', 'satori' ),
				'desc' => __( 'Private note for post authors', 'satori' )
			),
			# list
			'list' => array(
				'name' => 'List',
				'type' => 'wrap',
				'atts' => array(
					'style' => array(
						'values' => array(
							'star',
							'arrow',
							'check',
							'cross',
							'thumbs',
							'link',
							'gear',
							'time',
							'note',
							'plus',
							'guard',
							'event',
							'idea',
							'settings',
							'twitter'
						),
						'default' => 'star',
						'desc' => __( 'List style', 'satori' )
					)
				),
				'usage' => '[list style="check"] <ul> <li> List item </li> </ul> [/list]',
				'content' => '<ul><li>' . __( 'List item ', 'satori' ) . '</li></ul>',
				'desc' => __( 'Styled unordered list', 'satori' )
			),
			# feed
			'feed' => array(
				'name' => 'Feed',
				'type' => 'single',
				'atts' => array(
					'url' => array(
						'values' => array( ),
						'default' => '',
						'desc' => __( 'Feed URL', 'satori' )
					),
					'limit' => array(
						'values' => array(
							'1',
							'3',
							'5',
							'7',
							'10'
						),
						'default' => '3',
						'desc' => __( 'Number of item to show', 'satori' )
					)
				),
				'usage' => '[feed url="http://rss1.smashingmagazine.com/feed/" limit="5"]',
				'desc' => __( 'Feed grabber', 'satori' )
			),
			# menu
			'menu' => array(
				'name' => 'Menu',
				'type' => 'single',
				'atts' => array(
					'name' => array(
						'values' => array( ),
						'default' => '',
						'desc' => __( 'Custom menu name', 'satori' )
					)
				),
				'usage' => '[menu name="Main menu"]',
				'desc' => __( 'Custom menu by name', 'satori' )
			),
			# subpages
			'subpages' => array(
				'name' => 'Sub pages',
				'type' => 'single',
				'atts' => array(
					'depth' => array(
						'values' => array(
							'1',
							'2',
							'3'
						),
						'default' => '1',
						'desc' => __( 'Depth level', 'satori' )
					),
					'p' => array(
						'values' => false,
						'default' => '',
						'desc' => __( 'Parent page ID', 'satori' )
					)
				),
				'usage' => '[subpages]<br/>[subpages depth="2" p="122"]',
				'desc' => __( 'Page childrens', 'satori' )
			),
			# siblings
			'siblings' => array(
				'name' => 'Siblings',
				'type' => 'single',
				'atts' => array(
					'depth' => array(
						'values' => array(
							'1',
							'2',
							'3'
						),
						'default' => '1',
						'desc' => __( 'Depth level', 'satori' )
					)
				),
				'usage' => '[siblings]<br/>[siblings depth="2"]',
				'desc' => __( 'Page siblings', 'satori' )
			),
			# column
			'column' => array(
				'name' => 'Column',
				'type' => 'wrap',
				'atts' => array(
					'size' => array(
						'values' => array(
							'1-2',
							'1-3',
							'1-4',
							'1-5',
							'1-6',
							'2-3',
							'2-5',
							'3-4',
							'3-5',
							'4-5',
							'5-6'
						),
						'default' => '1-2',
						'desc' => __( 'Column width', 'satori' )
					),
					'last' => array(
						'values' => array(
							'0',
							'1'
						),
						'default' => '0',
						'desc' => __( 'Last column', 'satori' )
					),
					'style' => array(
						'values' => array(
							'0',
							'1',
							'2'
						),
						'default' => '0',
						'desc' => __( 'Column style', 'satori' )
					)
				),
				'usage' => '[column size="1-2"] Content [/column]<br/>[column size="1-2" last="1"] Content [/column]',
				'content' => __( 'Column content', 'satori' ),
				'desc' => __( 'Flexible columns', 'satori' )
			),
			# post list
			'display_posts' => array(
				'name' => 'Post List',
				'type' => 'single',
				'atts' => array(
					'numberposts' => array(
						'values' => array( ),
						'desc' => __( 'Number of posts to display', 'satori' )
					),
					'category' => array(
						'values' => array( ),
						'desc' => __( 'Post category', 'satori' )
					),
					'type' => array(
						'values' => array( ),
						'desc' => __( 'Project type', 'satori' )
					),
					'offset' => array(
						'values' => array( ),
						'desc' => __( 'Number of posts to skip', 'satori' )
					),
					'order' => array(
						'values' => array( 
							'DESC',
							'ASC'
						),
						'desc' => __( 'Display order', 'satori' )
					),
					'orderby' => array(
						'values' => array( 
						'date',
						'title',
						'modified',
						'rand'
						),
						'desc' => __( 'Order by', 'satori' )
					),
					'post_type' => array(
						'values' => array( 
						'post',
						'page',
						'project'
						),
						'desc' => __( 'Post type to display', 'satori' )
					)
				),
				'usage' => '[display-posts tag="advanced" posts_per_page="20"]<br>[display-posts id="14,3"]<br>[display-posts category="must-read" posts_per_page="-1" include_date="true" order="ASC" orderby="title"]',
				'desc' => __( 'List of posts satisfying given parameters', 'satori' )
			),
			# table
			'table' => array(
				'name' => 'Table',
				'type' => 'mixed',
				'atts' => array(
					'style' => array(
						'values' => array(
							'1',
							'2',
							'3'
						),
						'default' => '1',
						'desc' => __( 'Table style', 'satori' )
					),
					'file' => array(
						'values' => false,
						'default' => '',
						'desc' => __( 'Create table from CSV', 'satori' )
					)
				),
				'usage' => '[table style="1"] <table> … <table> [/table]<br/>[table style="1" file="http://example.com/file.csv"] [/table]',
				'content' => '<table><tr><td></td></tr></table>',
				'desc' => __( 'Styled table from HTML or CSV file', 'satori' )
			),
//			# pricing
//			'pricing' => array(
//				'name' => 'Pricing table',
//				'type' => 'wrap',
//				'atts' => array(
//					'style' => array(
//						'values' => array(
//							'1',
//							'2'
//						),
//						'default' => '1',
//						'desc' => __( 'Table style', 'satori' )
//					)
//				),
//				'usage' => '[pricing]<br/>[plan name="Plan 1"] Plan description [/plan]<br/>[/pricing]',
//				'content' => '[plan][/plan]',
//				'desc' => __( 'Customizable pricing table', 'satori' )
//			),
//			# plan
//			'plan' => array(
//				'name' => 'Pricing plan',
//				'type' => 'wrap',
//				'atts' => array(
//					'name' => array(
//						'values' => false,
//						'default' => '&hellip;',
//						'desc' => __( 'Plan name', 'satori' )
//					),
//					'price' => array(
//						'values' => false,
//						'default' => '$100',
//						'desc' => __( 'Plan price', 'satori' )
//					),
//					'per' => array(
//						'values' => false,
//						'default' => '$100',
//						'desc' => __( 'Price period', 'satori' )
//					),
//					'width' => array(
//						'values' => array(
//							'100',
//							'150',
//							'200',
//							'250'
//						),
//						'default' => '150',
//						'desc' => __( 'Box width', 'satori' )
//					),
//					'primary' => array(
//						'values' => array(
//							'0',
//							'1'
//						),
//						'default' => '0',
//						'desc' => __( 'Is primary plan?', 'satori' )
//					),
//					'class' => array(
//						'values' => false,
//						'default' => '',
//						'desc' => __( 'Custom box class', 'satori' )
//					)
//				),
//				'usage' => '[pricing]<br/>[plan name="Plan 1" price="$100" per="per month" width="150" primary="0"] Plan description [/plan]<br/>[/pricing]',
//				'content' => '<ul><li>List item</li></ul>[button link="#"]Choose[/button]',
//				'desc' => __( 'Customizable pricing table', 'satori' )
//			),
			# media
			'media' => array(
				'name' => 'Media',
				'type' => 'single',
				'atts' => array(
					'url' => array(
						'values' => false,
						'default' => '',
						'desc' => __( 'Media URL', 'satori' )
					),
					'width' => array(
						'values' => false,
						'default' => '600',
						'desc' => __( 'Width', 'satori' )
					),
					'height' => array(
						'values' => false,
						'default' => '400',
						'desc' => __( 'Height', 'satori' )
					),
					'jwplayer' => array(
						'values' => array(
							'',
							'autostart=true',
							'controlbar=bottom'
						),
						'default' => '',
						'desc' => __( 'jwPlayer url-encoded params', 'satori' )
					)
				),
				'usage' => '[media url="http://www.youtube.com/watch?v=2c2EEacfC1M"]<br/>[media url="http://vimeo.com/15069551"]<br/>[media url="video.mp4"]<br/>[media url="video.flv"]<br/>[media url="audio.mp3"]<br/>[media url="image.jpg"]<br/>[media url="video.flv" jwplayer="controlbar=bottom&autostart=true"]',
				'desc' => __( 'YouTube video, Vimeo video, .mp4/.flv video, .mp3 file or images', 'satori' )
			),
			# document
			'document' => array(
				'name' => 'Document',
				'type' => 'single',
				'atts' => array(
					'file' => array(
						'values' => false,
						'default' => '',
						'desc' => __( 'Document URL', 'satori' )
					),
					'width' => array(
						'values' => false,
						'default' => '600',
						'desc' => __( 'Width', 'satori' )
					),
					'height' => array(
						'values' => false,
						'default' => '400',
						'desc' => __( 'Height', 'satori' )
					)
				),
				'usage' => '[document file="file.doc" width="600" height="400"]',
				'desc' => __( '.doc, .xls, .pdf viewer by Google', 'satori' )
			),
			# gmap
			'gmap' => array(
				'name' => 'Gmap',
				'type' => 'single',
				'atts' => array(
					'width' => array(
						'values' => false,
						'default' => '600',
						'desc' => __( 'Width', 'satori' )
					),
					'height' => array(
						'values' => false,
						'default' => '400',
						'desc' => __( 'Height', 'satori' )
					),
					'address' => array(
						'values' => false,
						'default' => '',
						'desc' => __( 'Marker address', 'satori' )
					),
				),
				'usage' => '[gmap width="600" height="400" address="Russia, Moscow"]',
				'desc' => __( 'Maps by Google', 'satori' )
			),
			# nivo_slider
			'nivo_slider' => array(
				'name' => 'Nivo slider',
				'type' => 'single',
				'atts' => array(
					'source' => array(
						'values' => array(
							'post',
							'post=%post_id%',
							'cat=%cat_id%'
						),
						'default' => 'post',
						'desc' => __( 'Source of images', 'satori' )
					),
					'link' => array(
						'values' => array(
							'none',
							'image',
							'permalink',
							'caption',
							'meta'
						),
						'default' => 'image',
						'desc' => __( 'Images links', 'satori' )
					),
					'size' => array(
						'values' => array(
							'100x100',
							'150x150',
							'200x200',
							'300x200',
							'500x300'
						),
						'default' => '500x300',
						'desc' => __( 'Slider size', 'satori' )
					),
					'limit' => array(
						'values' => array(
							'3',
							'5',
							'10',
							'20'
						),
						'default' => '10',
						'desc' => __( 'Number of slides', 'satori' )
					),
					'effect' => array(
						'values' => array(
							'random',
							'boxRandom',
							'fold',
							'fade'
						),
						'default' => 'random',
						'desc' => __( 'Animation effect', 'satori' )
					),
					'speed' => array(
						'values' => false,
						'default' => '600',
						'desc' => __( 'Animation speed (1000 = 1 second)', 'satori' )
					),
					'delay' => array(
						'values' => false,
						'default' => '3000',
						'desc' => __( 'Animation delay (1000 = 1 second)', 'satori' )
					)
				),
				'usage' => '[nivo_slider]<br/>[nivo_slider source="post" link="image" size="500x300" limit="10" effect="boxRandom"]<br/>[nivo_slider source="cat=1" link="permalink" size="500x300" limit="10" effect="boxRandom"]',
				'desc' => __( 'Nivo slider by attached to post images', 'satori' )
			),
			# jcarousel
			'jcarousel' => array(
				'name' => 'jCarousel',
				'type' => 'single',
				'atts' => array(
					'source' => array(
						'values' => array(
							'post',
							'post=%post_id%',
							'cat=%cat_id%'
						),
						'default' => 'post',
						'desc' => __( 'Source of images', 'satori' )
					),
					'link' => array(
						'values' => array(
							'none',
							'image',
							'permalink',
							'caption',
							'meta'
						),
						'default' => 'image',
						'desc' => __( 'Images links', 'satori' )
					),
					'size' => array(
						'values' => array(
							'100x100',
							'150x150',
							'200x200',
							'150x300'
						),
						'default' => '150x150',
						'desc' => __( 'Carousel item size', 'satori' )
					),
					'limit' => array(
						'values' => array(
							'3',
							'5',
							'10',
							'20'
						),
						'default' => '10',
						'desc' => __( 'Number of items', 'satori' )
					),
					'items' => array(
						'values' => array(
							'3',
							'4',
							'5'
						),
						'default' => '3',
						'desc' => __( 'Number of items in viewport', 'satori' )
					),
					'speed' => array(
						'values' => false,
						'default' => '400',
						'desc' => __( 'Animation speed (1000 = 1 second)', 'satori' )
					),
					'margin' => array(
						'values' => array(
							'5',
							'10',
							'15'
						),
						'default' => '10',
						'desc' => __( 'Space between items in pixels', 'satori' )
					)
				),
				'usage' => '[jcarousel]<br/>[jcarousel source="post" link="image" size="150x150" limit="10" items="3"]<br/>[jcarousel source="cat=1" link="permalink" size="150x150" limit="10" items="3"]',
				'desc' => __( 'jCarousel by attached to post images', 'satori' )
			),
			# custom_gallery
			'custom_gallery' => array(
				'name' => 'Custom gallery',
				'type' => 'single',
				'atts' => array(
					'style' => array(
						'values' => array(
							'1'
						),
						'default' => '1',
						'desc' => __( 'Gallery style', 'satori' )
					),
					'source' => array(
						'values' => array(
							'post',
							'post=%post_id%',
							'cat=%cat_id%'
						),
						'default' => 'post',
						'desc' => __( 'Source of images', 'satori' )
					),
					'link' => array(
						'values' => array(
							'none',
							'image',
							'permalink',
							'caption',
							'meta'
						),
						'default' => 'image',
						'desc' => __( 'Images links', 'satori' )
					),
					'description' => array(
						'values' => array(
							'0',
							'1'
						),
						'default' => '0',
						'desc' => __( 'Show image description', 'satori' )
					),
					'size' => array(
						'values' => array(
							'100x100',
							'150x150',
							'200x200',
							'150x300'
						),
						'default' => '200x200',
						'desc' => __( 'Gallery item size', 'satori' )
					),
					'limit' => array(
						'values' => array(
							'3',
							'5',
							'10',
							'20'
						),
						'default' => '10',
						'desc' => __( 'Number of items', 'satori' )
					)
				),
				'usage' => '[custom_gallery]<br/>[custom_gallery source="post" link="image" size="200x200" limit="10"]<br/>[custom_gallery source="cat=1" link="permalink" size="200x200" limit="10"]',
				'desc' => __( 'Custom gallery by attached to post images', 'satori' )
			),
			# tweets
			'tweets' => array(
				'name' => 'Tweets',
				'type' => 'single',
				'atts' => array(
					'username' => array(
						'values' => array( ),
						'default' => 'twitter',
						'desc' => __( 'Twitter username', 'satori' )
					),
					'limit' => array(
						'values' => array(
							'1',
							'3',
							'5',
							'7',
							'10'
						),
						'default' => '3',
						'desc' => __( 'Number of tweets to show', 'satori' )
					),
					'style' => array(
						'values' => array(
							'1',
							'2'
						),
						'default' => '1',
						'desc' => __( 'Tweets style', 'satori' )
					),
					'show_time' => array(
						'values' => array(
							'0',
							'1'
						),
						'default' => '1',
						'desc' => __( 'Show relative time', 'satori' )
					)
				),
				'usage' => '[tweets username="gn_themes" limit="3" style="1" show_time="1"]',
				'desc' => __( 'Recent tweets', 'satori' )
			),
		);

		if ( $shortcode )
			return $shortcodes[$shortcode];
		else
			return $shortcodes;
	}

?>